# Pentanol (Amyl alcohol), C5H12O

## Chemical formula

- Normal amyl alcohol: CH3CH2CH2CH2OH or C5H11OH
- Isoamyl alcohol: (CH3)2CHCH2CH2OH

## Other names

Normal amyl alcohol | Isoamyl alcohol
--- | ---
1-Pentanol n-Pentanol Pentan-1-ol | 3-Methyl-1-Butanol 3-Methylbutan-1-ol Isopentyl alcohol Isopentanol Isobutylcarbinol

## External links

- Amyl alcohol - Wikipedia
- 1-Pentanol - Wikipedia
- 1-Pentanol - NIST Chemistry WebBook
- Isoamyl alcohol - Wikipedia
- 1-Butanol, 3-methyl- - NIST Chemistry WebBook